@@ -31,8 +31,8 @@ test_that("composition of functions shows composite functions", {
     "",
     "[[\"inc\"]]",
     "  <Partially Applied Function>",
-    "  function(.y) {",
-    "    (^1) + .y",
+    "  function(e2) {",
+    "    (^1) + e2",
     "  }",
     "",
     "[[\"res\"]][[1]]",
